pub struct MessageAddress { /* private fields */ }Expand description
Represents the addressable endpoint of an actor, combining its identity and inbox channel.
A MessageAddress contains the necessary information to send a message to a specific
actor: its unique identifier (sender, an Ern) and the sender half (address)
of the MPSC channel connected to its inbox.
This struct is typically used within message envelopes ([OutboundEnvelope]) to specify
the sender and recipient of a message.
Implementations